@@ -84,6 +84,10 @@
       $(".globaltoc-container").remove();
     }
 
+    // Local TOC.
+    $(".bs-sidenav ul").addClass("nav nav-list");
+    $(".bs-sidenav > ul > li > a").addClass("nav-header");
+
     // Local TOC.
     patchToc($("ul.localtoc"), 2);
 
